==> kgpg_16.08.3.orig.tar.xz: kgpg-16.08.3/core/emailvalidator.cpp <==
/***************************************************************************
 *   Copyright (C) 2006 by Jimmy Gilles                                    *
 *   jimmygilles@gmail.com                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/

#include "emailvalidator.h"

#include "kpimutils/email.h"

namespace KgpgCore
{

QValidator::State EmailValidator::validate(QString &input, int &) const
{
    if (KPIMUtils::isValidSimpleAddress(input))
        return QValidator::Acceptable;
    else
        return QValidator::Invalid;
}

} // namespace KgpgCore

==> kgpg-21.03.90.tar.xz: kgpg-21.03.90/core/emailvalidator.cpp <==
/***************************************************************************
 *   Copyright (C) 2006 by Jimmy Gilles                                    *
 *   jimmygilles@gmail.com                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
 ***************************************************************************/

#include "emailvalidator.h"

#include <KEmailAddress>

namespace KgpgCore
{

QValidator::State EmailValidator::validate(QString &input, int &) const
{
    if (KEmailAddress::isValidSimpleAddress(input))
        return QValidator::Acceptable;
    else
        return QValidator::Invalid;
}

} // namespace KgpgCore
